==> android-1.12.0-sources.jar: io/primer/android/di/AsyncPaymentMethodModule.kt <==
package io.primer.android.di

import io.primer.android.data.deeplink.async.AsyncPaymentMethodDeeplinkDataRepository
import io.primer.android.data.payments.async.datasource.RemoteAsyncPaymentMethodStatusDataSource
import io.primer.android.data.payments.async.repository.AsyncPaymentMethodStatusDataRepository
import io.primer.android.domain.deeplink.async.AsyncPaymentMethodDeeplinkInteractor
import io.primer.android.domain.deeplink.async.repository.AsyncPaymentMethodDeeplinkRepository
import io.primer.android.domain.payments.async.AsyncPaymentMethodInteractor
import io.primer.android.domain.payments.async.repository.AsyncPaymentMethodStatusRepository
import io.primer.android.presentation.payment.async.AsyncPaymentMethodViewModel
import org.koin.android.viewmodel.dsl.viewModel
import org.koin.dsl.module

internal val asyncPaymentMethodModule = {
    module {
        single {
            RemoteAsyncPaymentMethodStatusDataSource(
                get(),
            )
        }
        single<AsyncPaymentMethodStatusRepository> {
            AsyncPaymentMethodStatusDataRepository(
                get(),
            )
        }
        single<AsyncPaymentMethodDeeplinkRepository> {
            AsyncPaymentMethodDeeplinkDataRepository(
                get(),
            )
        }
        single {
            AsyncPaymentMethodInteractor(
                get(),
                get(),
                get(),
                get()
            )
        }
        single {
            AsyncPaymentMethodDeeplinkInteractor(
                get(),
            )
        }

        viewModel { AsyncPaymentMethodViewModel(get(), get()) }
    }
}

==> android-2.5.0-sources.jar: io/primer/android/di/AsyncPaymentMethodModule.kt <==
package io.primer.android.di

import io.primer.android.data.deeplink.async.AsyncPaymentMethodDeeplinkDataRepository
import io.primer.android.data.payments.async.datasource.RemoteAsyncPaymentMethodStatusDataSource
import io.primer.android.data.payments.async.repository.AsyncPaymentMethodStatusDataRepository
import io.primer.android.domain.deeplink.async.AsyncPaymentMethodDeeplinkInteractor
import io.primer.android.domain.deeplink.async.repository.AsyncPaymentMethodDeeplinkRepository
import io.primer.android.domain.payments.async.AsyncPaymentMethodInteractor
import io.primer.android.domain.payments.async.repository.AsyncPaymentMethodStatusRepository
import io.primer.android.presentation.payment.async.AsyncPaymentMethodViewModel
import org.koin.androidx.viewmodel.dsl.viewModel
import org.koin.dsl.module

internal val asyncPaymentMethodModule = {
    module {
        single {
            RemoteAsyncPaymentMethodStatusDataSource(
                get(),
            )
        }
        single<AsyncPaymentMethodStatusRepository> {
            AsyncPaymentMethodStatusDataRepository(
                get(),
            )
        }
        single<AsyncPaymentMethodDeeplinkRepository> {
            AsyncPaymentMethodDeeplinkDataRepository(
                get(),
            )
        }
        single {
            AsyncPaymentMethodInteractor(
                get(),
                get(),
                get(),
                get()
            )
        }
        single {
            AsyncPaymentMethodDeeplinkInteractor(
                get(),
            )
        }

        viewModel { AsyncPaymentMethodViewModel(get(), get()) }
    }
}
